@@ -71,25 +71,23 @@ _ResultsFromKeyFunc = Callable[
 
 
 class BerkeleyDB(Store):
-    """\
-    A store that allows for on-disk persistent using BerkeleyDB, a fast
-    key/value DB.
+    """A store that allows for on-disk persistent using BerkeleyDB, a fast key/value DB.
 
     This store implementation used to be known, previous to rdflib 6.0.0
     as 'Sleepycat' due to that being the then name of the Python wrapper
     for BerkeleyDB.
 
     This store allows for quads as well as triples. See examples of use
-    in both the `examples.berkeleydb_example` and ``test/test_store/test_store_berkeleydb.py``
+    in both the `examples.berkeleydb_example` and `test/test_store/test_store_berkeleydb.py`
     files.
 
     **NOTE on installation**:
 
     To use this store, you must have BerkeleyDB installed on your system
-    separately to Python (``brew install berkeley-db`` on a Mac) and also have
-    the BerkeleyDB Python wrapper installed (``pip install berkeleydb``).
+    separately to Python (`brew install berkeley-db` on a Mac) and also have
+    the BerkeleyDB Python wrapper installed (`pip install berkeleydb`).
     You may need to install BerkeleyDB Python wrapper like this:
-    ``YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION=1 pip install berkeleydb``
+    `YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION=1 pip install berkeleydb`
     """
 
     context_aware = True
